@@ -18,11 +18,11 @@ our @EXPORT_OK = qw(
 	modelsdir
 ); # symbols to export on request (WHY?)
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 
 BEGIN {
-    $VERSION = '0.2';
+    $VERSION = '0.3';
     if ($] > 5.006) {
         require XSLoader;
         XSLoader::load(__PACKAGE__, $VERSION);
@@ -84,18 +84,29 @@ Image::DecodeQR::WeChat - Decode QR code(s) from images using the OpenCV/WeChat
 
 =head1 VERSION
 
-Version 0.2
+Version 0.3
 
 
 =head1 SYNOPSIS
 
+This module provides a Perl interface to the OpenCV/WeChat QR code
+decoder via XS code.
+OpenCV/WeChat library uses CNN to do this with pre-trained models.
+
+This module has been tested with OpenCV v4.5.5 and Perl v5.32 on
+Linux.
+
+The library is relatively successful even for rotated codes. It remains
+to be tested on the minimum size ofthe code images (60px in my case).
+
+Here is some code to get you started:
+
     # this ensures that both input params can contain utf8 strings
     # but also results (somehow but beyond me)
-    use utf8;
     use Image::DecodeQR::WeChat;
 
     # this will be fixed, right now params are hardoded in XS code
-    my $payloads = Image::DecodeQR::WeChat::decode_xs(
+    my $ret = Image::DecodeQR::WeChat::decode_xs(
 	# the input image containing one or more QR-codes
 	'an-input-image.png',
 
@@ -128,8 +139,19 @@ Version 0.2
 	# only if outbase was specified
 	1,
     );
-    die "failed" unless $payloads;
-    print "Payload got: $_\n" for (@$payloads);
+    die "failed" unless $ret;
+    # we got back an array-of-2-arrays
+    # * one contains the QR-code-text (called payload)
+    # * one contains bounding boxes, one for each payload
+    # we have as many payloads and bounding boxes as
+    # are the QR-codes detected (some may have been skipped)
+    
+    my ($payloads, $boundingboxes) = @$ret;
+    for (0..$#$payloads){
+      print "Payload got: '".$payloads->[$_]
+        ."' bbox: @{$boundingboxes->[$_]}"
+        .".\n";
+    }
 
     # The above decode_xs() expects all parameters to be present
     # while decode() below takes a hash of params and fills the
@@ -137,7 +159,7 @@ Version 0.2
     # So, it is still calling XS code but via a Perl sub
     # The important bit is that the modelsdir is filled in automatically
     # rather than the user looking for it
-    my $payloads = Image::DecodeQR::WeChat::decode({
+    my $ret = Image::DecodeQR::WeChat::decode({
         # these are required
         'input' => 'input.jpg',
         'outbase' => 'outs',
@@ -147,8 +169,16 @@ Version 0.2
         #'graphicaldisplayresult'' => 0,
         #'dumpqrimagestofile' => 0,
     });
-    die "failed" unless $payloads;
-    print "Payload got: $_\n" for (@$payloads);
+    die "failed" unless $ret;
+    my ($payloads, $boundingboxes) = @$ret;
+    for (0..$#$payloads){
+      print "Payload got: '".$payloads->[$_]
+        ."' bbox: @{$boundingboxes->[$_]}"
+        .".\n";
+    }
+
+    # pre-trained models location (installed with this module)
+    print "my models are in here: ".Image::DecodeQR::WeChat::modelsdir()."\n"
 
 
 This code calls functions and methods from OpenCV/WeChat library (written in C++)
@@ -157,7 +187,7 @@ It's just that: a very thin wrapper of a C++ library written in XS. It only inte
 the OpenCV/WeChat library for QR code decoding.
 
 It can detect multiple QR codes embeded in a single image. And has been
-successfully tested with as small sizes as 55 x 55 px.
+successfully tested with as small sizes as 60 x 60 px.
 
 The payload(s) (the QR-code's text) are returned back as an ARRAYref.
 
@@ -175,7 +205,6 @@ interface other parts of the OpenCV library:
 
 =head1 EXPORT
 
-
 =over
 
 =item C<decode()>
@@ -187,6 +216,15 @@ interface other parts of the OpenCV library:
 =back
 
 
+=head1 COMMAND LINE SCRIPT
+
+  image-decodeqr-wechat.pl --input in.jpg
+
+  image-decodeqr-wechat.pl --help
+
+A CLI script is provided and will be installed by this module. Basic usage is as above.
+
+
 =head1 SUBROUTINES/METHODS
 
 
